@@ -205,17 +205,9 @@ public:
      */
     void resetZoomLevel();
 
-    /**
-     * Updates the view properties of the current URL to the
-     * sorting given by \a role.
-     */
     void setSortRole(const QByteArray &role);
     QByteArray sortRole() const;
 
-    /**
-     * Updates the view properties of the current URL to the
-     * sort order given by \a order.
-     */
     void setSortOrder(Qt::SortOrder order);
     Qt::SortOrder sortOrder() const;
 
@@ -732,6 +724,18 @@ private Q_SLOTS:
      */
     void slotStatJobResult(KJob *job);
 
+    /**
+     * Updates the view properties of the current URL to the
+     * sorting given by \a role.
+     */
+    void updateSortRole(const QByteArray &role);
+
+    /**
+     * Updates the view properties of the current URL to the
+     * sort order given by \a order.
+     */
+    void updateSortOrder(Qt::SortOrder order);
+
     /**
      * Updates the view properties of the current URL to the
      * sorting of files and folders (separate with folders first or mixed) given by \a foldersFirst.
